@@ -13,7 +13,9 @@ logger = logging.getLogger(__name__)
 
 
 class Array(abstract_array.AbstractArray):
-    def __new__(cls, array, mask, store_in_1d=True, *args, **kwargs):
+    def __new__(
+        cls, array, mask, exposure_info=None, store_in_1d=True, *args, **kwargs
+    ):
         """An array of values, which are paired to a uniform 2D mask of pixels and sub-pixels. Each entry
         on the array corresponds to a value at the centre of a sub-pixel in an unmasked pixel.
 
@@ -181,15 +183,13 @@ class Array(abstract_array.AbstractArray):
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
         """
 
-        if store_in_1d and len(array.shape) != 1:
-            raise exc.ArrayException(
-                "An array input into the arrays.Array.__new__ method has store_in_1d = True but"
-                "the input shape of the array is not 1."
-            )
-
         obj = array.view(cls)
         obj.mask = mask
+        obj.exposure_info = exposure_info
         obj.store_in_1d = store_in_1d
+
+        abstract_array.check_array(array=obj)
+
         return obj
 
     @classmethod
@@ -200,6 +200,7 @@ class Array(abstract_array.AbstractArray):
         pixel_scales=None,
         sub_size=1,
         origin=(0.0, 0.0),
+        exposure_info=None,
         store_in_1d=True,
     ):
         """Create an Array (see *AbstractArray.__new__*) by inputting the array values in 1D, for example:
@@ -249,11 +250,19 @@ class Array(abstract_array.AbstractArray):
         array = abstract_array.convert_manual_1d_array(
             array_1d=array, mask=mask, store_in_1d=store_in_1d
         )
-        return Array(array=array, mask=mask, store_in_1d=store_in_1d)
+        return cls(
+            array=array, mask=mask, exposure_info=exposure_info, store_in_1d=store_in_1d
+        )
 
     @classmethod
     def manual_2d(
-        cls, array, pixel_scales=None, sub_size=1, origin=(0.0, 0.0), store_in_1d=True
+        cls,
+        array,
+        pixel_scales=None,
+        sub_size=1,
+        origin=(0.0, 0.0),
+        exposure_info=None,
+        store_in_1d=True,
     ):
         """Create an Array (see *AbstractArray.__new__*) by inputting the array values in 2D, for example:
 
@@ -301,7 +310,84 @@ class Array(abstract_array.AbstractArray):
         array = abstract_array.convert_manual_2d_array(
             array_2d=array, mask=mask, store_in_1d=store_in_1d
         )
-        return Array(array=array, mask=mask, store_in_1d=store_in_1d)
+        return cls(array=array, mask=mask, store_in_1d=store_in_1d)
+
+    @classmethod
+    def manual(
+        cls,
+        array,
+        shape_2d=None,
+        pixel_scales=None,
+        sub_size=1,
+        origin=(0.0, 0.0),
+        exposure_info=None,
+        store_in_1d=True,
+    ):
+        """Create an Array (see *AbstractArray.__new__*) by inputting the array values in 1D or 2D, automatically
+        determining whether to use the 'manual_1d' or 'manual_2d' methods.
+
+        See the manual_1d and manual_2d methods for examples.
+
+        Parameters
+        ----------
+        array : np.ndarray or list
+            The values of the array input as an ndarray of shape [total_unmasked_pixels*(sub_size**2)] or a list of
+            lists.
+        shape_2d : (float, float)
+            The 2D shape of the mask the array is paired with.
+        pixel_scales : (float, float) or float
+            The pixel conversion scale of a pixel in the y and x directions. If input as a float, the pixel_scales
+            are converted to the format (float, float).
+        sub_size : int
+            The size (sub_size x sub_size) of each unmasked pixels sub-array.
+        origin : (float, float)
+            The origin of the array's mask.
+        store_in_1d : bool
+            If True, the array is stored in 1D as an ndarray of shape [total_unmasked_pixels]. If False, it is
+            stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
+        """
+        if len(array.shape) == 1:
+            return cls.manual_1d(
+                array=array,
+                shape_2d=shape_2d,
+                pixel_scales=pixel_scales,
+                sub_size=sub_size,
+                origin=origin,
+                store_in_1d=store_in_1d,
+            )
+        return cls.manual_2d(
+            array=array,
+            pixel_scales=pixel_scales,
+            sub_size=sub_size,
+            origin=origin,
+            store_in_1d=store_in_1d,
+        )
+
+    @classmethod
+    def manual_mask(cls, array, mask, exposure_info=None, store_in_1d=True):
+        """Create a Array (see *AbstractArray.__new__*) by inputting the array values in 1D or 2D with its mask,
+        for example:
+
+        mask = Mask([[True, False, False, False])
+        array=np.array([1.0, 2.0, 3.0])
+
+        Parameters
+        ----------
+        array : np.ndarray or list
+            The values of the array input as an ndarray of shape [total_unmasked_pixels*(sub_size**2)] or a list of
+            lists.
+        mask : Mask
+            The mask whose masked pixels are used to setup the sub-pixel grid.
+        store_in_1d : bool
+            If True, the array is stored in 1D as an ndarray of shape [total_unmasked_pixels]. If False, it is
+            stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
+        """
+        array = abstract_array.convert_manual_array(
+            array=array, mask=mask, store_in_1d=store_in_1d
+        )
+        return cls(
+            array=array, mask=mask, exposure_info=exposure_info, store_in_1d=store_in_1d
+        )
 
     @classmethod
     def full(
@@ -311,6 +397,7 @@ class Array(abstract_array.AbstractArray):
         pixel_scales=None,
         sub_size=1,
         origin=(0.0, 0.0),
+        exposure_info=None,
         store_in_1d=True,
     ):
         """Create a Array (see *AbstractArray.__new__*) where all values are filled with an input fill value, analogous to
@@ -354,6 +441,7 @@ class Array(abstract_array.AbstractArray):
         pixel_scales=None,
         sub_size=1,
         origin=(0.0, 0.0),
+        exposure_info=None,
         store_in_1d=True,
     ):
         """Create an Array (see *AbstractArray.__new__*) where all values are filled with ones, analogous to the method numpy
@@ -393,6 +481,7 @@ class Array(abstract_array.AbstractArray):
         pixel_scales=None,
         sub_size=1,
         origin=(0.0, 0.0),
+        exposure_info=None,
         store_in_1d=True,
     ):
         """Create an Array (see *AbstractArray.__new__*) where all values are filled with zeros, analogous to the method numpy
@@ -466,7 +555,7 @@ class Array(abstract_array.AbstractArray):
 
     @classmethod
     def manual_yx_and_values(
-        cls, y, x, values, shape_2d, sub_size=1, pixel_scales=None
+        cls, y, x, values, shape_2d, sub_size=1, pixel_scales=None, exposure_info=None
     ):
         """Create a Array (see *AbstractArray.__new__*) by inputting the y and x pixel values where the array is filled
         and the values to fill the array, for example:
@@ -521,150 +610,5 @@ class Array(abstract_array.AbstractArray):
             pixel_scales=pixel_scales,
             shape_2d=shape_2d,
             sub_size=sub_size,
+            exposure_info=exposure_info,
         )
-
-
-class MaskedArray(abstract_array.AbstractArray):
-    def __new__(cls, array, mask, store_in_1d=True, *args, **kwargs):
-
-        if store_in_1d and len(array.shape) != 1:
-            raise exc.ArrayException(
-                "An array input into the arrays.Array.__new__ method has store_in_1d = True but"
-                "the input shape of the array is not 1."
-            )
-
-        obj = array.view(cls)
-        obj.mask = mask
-        obj.store_in_1d = store_in_1d
-        return obj
-
-    @classmethod
-    def manual_1d(cls, array, mask, store_in_1d=True):
-        """Create a Array (see *AbstractArray.__new__*) by inputting the array values in 1D with its mask, for example:
-
-        mask = Mask([[True, False, False, False])
-        array=np.array([1.0, 2.0, 3.0])
-
-        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_2d must be
-        input into this method. The mask is setup as a unmasked *Mask* of shape_2d.
-
-        Parameters
-        ----------
-        array : np.ndarray or list
-            The values of the array input as an ndarray of shape [total_unmasked_pixels*(sub_size**2)] or a list of
-            lists.
-        mask : Mask
-            The mask whose masked pixels are used to setup the sub-pixel grid.
-        store_in_1d : bool
-            If True, the array is stored in 1D as an ndarray of shape [total_unmasked_pixels]. If False, it is
-            stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
-        """
-        array = abstract_array.convert_manual_1d_array(
-            array_1d=array, mask=mask, store_in_1d=store_in_1d
-        )
-        return Array(array=array, mask=mask, store_in_1d=store_in_1d)
-
-    @classmethod
-    def manual_2d(cls, array, mask, store_in_1d=True):
-        """Create an Array (see *AbstractArray.__new__*) by inputting the array values in 2D with its mask, for example:
-
-        mask = Mask([[True, False, False, False])
-        array=np.ndarray([[1.0, 2.0],
-                         [3.0, 4.0]])
-
-        array=[[1.0, 2.0],
-              [3.0, 4.0]]
-
-        Mask values are removed, such that the grid in 1D will be of length 3, omitting the values 1.0.
-
-        Parameters
-        ----------
-        array : np.ndarray or list
-            The values of the array input as an ndarray of shape [total_y_pixels*sub_size, total_x_pixel*sub_size] or a
-             list of lists.
-        mask : Mask
-            The mask whose masked pixels are used to setup the sub-pixel grid.
-        store_in_1d : bool
-            If True, the array is stored in 1D as an ndarray of shape [total_unmasked_pixels]. If False, it is
-            stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
-        """
-        array = abstract_array.convert_manual_2d_array(
-            array_2d=array, mask=mask, store_in_1d=store_in_1d
-        )
-        return Array(array=array, mask=mask, store_in_1d=store_in_1d)
-
-    @classmethod
-    def full(cls, fill_value, mask, store_in_1d=True):
-        """Create an Array (see *AbstractArray.__new__*) where all values are filled with an input fill value, with the
-         corresponding mask input.
-
-        Parameters
-        ----------
-        fill_value : float
-            The value all array elements are filled with.
-         mask : Mask
-            The mask whose masked pixels are used to setup the sub-pixel grid.
-        store_in_1d : bool
-            If True, the array is stored in 1D as an ndarray of shape [total_unmasked_pixels]. If False, it is
-            stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
-        """
-        return cls.manual_2d(
-            array=np.full(fill_value=fill_value, shape=mask.sub_shape_2d),
-            mask=mask,
-            store_in_1d=store_in_1d,
-        )
-
-    @classmethod
-    def ones(cls, mask, store_in_1d=True):
-        """Create an Array (see *AbstractArray.__new__*) where all values are filled with ones,  with the
-         corresponding mask input.
-
-        Parameters
-        ----------
-        shape_2d : (float, float)
-            The 2D shape of the mask the array is paired with.
-         mask : Mask
-            The mask whose masked pixels are used to setup the sub-pixel grid.
-        store_in_1d : bool
-            If True, the array is stored in 1D as an ndarray of shape [total_unmasked_pixels]. If False, it is
-            stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
-        """
-        return cls.full(fill_value=1.0, mask=mask, store_in_1d=store_in_1d)
-
-    @classmethod
-    def zeros(cls, mask, store_in_1d=True):
-        """Create an Array (see *AbstractArray.__new__*) where all values are filled with zeros, with the
-         corresponding mask input.
-
-        Parameters
-        ----------
-        shape_2d : (float, float)
-            The 2D shape of the mask the array is paired with.
-          mask : Mask
-            The mask whose masked pixels are used to setup the sub-pixel grid.
-        store_in_1d : bool
-            If True, the array is stored in 1D as an ndarray of shape [total_unmasked_pixels]. If False, it is
-            stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
-        """
-        return cls.full(fill_value=0.0, mask=mask, store_in_1d=store_in_1d)
-
-    @classmethod
-    def from_fits(cls, file_path, hdu, mask, store_in_1d=True):
-        """Create an Array (see *AbstractArray.__new__*) by loaing the array values from a .fits file, with the
-         corresponding mask input.
-
-        Parameters
-        ----------
-        file_path : str
-            The path the file is output to, including the filename and the '.fits' extension,
-            e.g. '/path/to/filename.fits'
-        hdu : int
-            The Header-Data Unit of the .fits file the array data is loaded from.
-          mask : Mask
-            The mask whose masked pixels are used to setup the sub-pixel grid.
-        store_in_1d : bool
-            If True, the array is stored in 1D as an ndarray of shape [total_unmasked_pixels]. If False, it is
-            stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
-        """
-        array_2d = array_util.numpy_array_2d_from_fits(file_path=file_path, hdu=hdu)
-        return cls.manual_2d(array=array_2d, mask=mask, store_in_1d=store_in_1d)
