@@ -50,10 +50,12 @@ class TestImaging:
     def test__new_imaging_with_signal_to_noise_limit__limit_above_max_signal_to_noise__signal_to_noise_map_unchanged(
         self
     ):
-        image = aa.Array.full(fill_value=20.0, shape_2d=(2, 2))
+        image = aa.Array.full(fill_value=20.0, shape_2d=(2, 2), store_in_1d=True)
         image[3] = 5.0
 
-        noise_map_array = aa.Array.full(fill_value=5.0, shape_2d=(2, 2))
+        noise_map_array = aa.Array.full(
+            fill_value=5.0, shape_2d=(2, 2), store_in_1d=True
+        )
         noise_map_array[3] = 2.0
 
         imaging = aa.Imaging(
@@ -64,16 +66,34 @@ class TestImaging:
             signal_to_noise_limit=100.0
         )
 
-        assert (imaging.image.in_2d == np.array([[20.0, 20.0], [20.0, 5.0]])).all()
+        assert (imaging.image == np.array([20.0, 20.0, 20.0, 5.0])).all()
 
-        assert (imaging.noise_map.in_2d == np.array([[5.0, 5.0], [5.0, 2.0]])).all()
+        assert (imaging.noise_map == np.array([5.0, 5.0, 5.0, 2.0])).all()
 
-        assert (
-            imaging.signal_to_noise_map.in_2d == np.array([[4.0, 4.0], [4.0, 2.5]])
-        ).all()
+        assert (imaging.signal_to_noise_map == np.array([4.0, 4.0, 4.0, 2.5])).all()
 
         assert (imaging.psf.in_2d == np.zeros((3, 3))).all()
 
+        image = aa.Array.full(fill_value=20.0, shape_2d=(2, 2), store_in_1d=False)
+        image[1, 1] = 5.0
+
+        noise_map_array = aa.Array.full(
+            fill_value=5.0, shape_2d=(2, 2), store_in_1d=False
+        )
+        noise_map_array[1, 1] = 2.0
+
+        imaging = aa.Imaging(image=image, noise_map=noise_map_array)
+
+        imaging = imaging.signal_to_noise_limited_from_signal_to_noise_limit(
+            signal_to_noise_limit=100.0
+        )
+
+        assert (imaging.image == np.array([[20.0, 20.0], [20.0, 5.0]])).all()
+
+        assert (imaging.noise_map == np.array([[5.0, 5.0], [5.0, 2.0]])).all()
+
+        assert (imaging.signal_to_noise_map == np.array([[4.0, 4.0], [4.0, 2.5]])).all()
+
     def test__new_imaging_with_signal_to_noise_limit_below_max_signal_to_noise__signal_to_noise_map_capped_to_limit(
         self
     ):
@@ -203,6 +223,26 @@ class TestImaging:
         assert imaging.noise_map.mask.pixel_scales == (0.1, 0.1)
 
 
+class TestSettingsMaskedImaging:
+    def test__bin_up_factor_tag(self):
+
+        settings = aa.SettingsMaskedImaging(bin_up_factor=None)
+        assert settings.bin_up_factor_tag == ""
+        settings = aa.SettingsMaskedImaging(bin_up_factor=1)
+        assert settings.bin_up_factor_tag == ""
+        settings = aa.SettingsMaskedImaging(bin_up_factor=2)
+        assert settings.bin_up_factor_tag == "__bin_2"
+
+    def test__psf_shape_2d_tag(self):
+
+        settings = aa.SettingsMaskedImaging(psf_shape_2d=None)
+        assert settings.psf_shape_tag == ""
+        settings = aa.SettingsMaskedImaging(psf_shape_2d=(2, 2))
+        assert settings.psf_shape_tag == "__psf_2x2"
+        settings = aa.SettingsMaskedImaging(psf_shape_2d=(3, 4))
+        assert settings.psf_shape_tag == "__psf_3x4"
+
+
 class TestMaskedImaging:
     def test__masked_dataset(self, imaging_7x7, sub_mask_7x7):
 
@@ -222,7 +262,6 @@ class TestMaskedImaging:
 
         assert (masked_imaging_7x7.psf.in_1d == (1.0 / 9.0) * np.ones(9)).all()
         assert (masked_imaging_7x7.psf.in_2d == (1.0 / 9.0) * np.ones((3, 3))).all()
-        assert masked_imaging_7x7.psf_shape_2d == (3, 3)
 
     def test__grid(
         self,
@@ -234,7 +273,9 @@ class TestMaskedImaging:
         grid_iterate_7x7,
     ):
         masked_imaging_7x7 = aa.MaskedImaging(
-            imaging=imaging_7x7, mask=sub_mask_7x7, grid_class=aa.Grid
+            imaging=imaging_7x7,
+            mask=sub_mask_7x7,
+            settings=aa.SettingsMaskedImaging(grid_class=aa.Grid),
         )
 
         assert isinstance(masked_imaging_7x7.grid, aa.Grid)
@@ -244,7 +285,9 @@ class TestMaskedImaging:
         assert (masked_imaging_7x7.blurring_grid.in_1d == blurring_grid_7x7).all()
 
         masked_imaging_7x7 = aa.MaskedImaging(
-            imaging=imaging_7x7, mask=sub_mask_7x7, grid_class=aa.GridIterate
+            imaging=imaging_7x7,
+            mask=sub_mask_7x7,
+            settings=aa.SettingsMaskedImaging(grid_class=aa.GridIterate),
         )
 
         assert isinstance(masked_imaging_7x7.grid, aa.GridIterate)
@@ -255,8 +298,9 @@ class TestMaskedImaging:
         masked_imaging_7x7 = aa.MaskedImaging(
             imaging=imaging_7x7,
             mask=sub_mask_7x7,
-            grid_class=aa.GridInterpolate,
-            pixel_scales_interp=1.0,
+            settings=aa.SettingsMaskedImaging(
+                grid_class=aa.GridInterpolate, pixel_scales_interp=1.0
+            ),
         )
 
         grid = aa.GridInterpolate.from_mask(mask=sub_mask_7x7, pixel_scales_interp=1.0)
@@ -280,6 +324,55 @@ class TestMaskedImaging:
         assert type(masked_imaging_7x7.psf) == aa.Kernel
         assert type(masked_imaging_7x7.convolver) == aa.Convolver
 
+    def test__masked_imaging__uses_bin_up_factor(self, imaging_7x7, mask_7x7_1_pix):
+
+        masked_imaging_7x7 = aa.MaskedImaging(
+            imaging=imaging_7x7,
+            mask=mask_7x7_1_pix,
+            settings=aa.SettingsMaskedImaging(grid_class=aa.Grid, bin_up_factor=2),
+        )
+
+        binned_up_imaging = imaging_7x7.binned_from_bin_up_factor(bin_up_factor=2)
+        binned_up_mask = mask_7x7_1_pix.binned_mask_from_bin_up_factor(bin_up_factor=2)
+
+        assert (
+            masked_imaging_7x7.image.in_2d
+            == binned_up_imaging.image.in_2d * np.invert(binned_up_mask)
+        ).all()
+
+        assert (masked_imaging_7x7.psf == (1.0 / 9.0) * binned_up_imaging.psf).all()
+        assert (
+            masked_imaging_7x7.noise_map.in_2d
+            == binned_up_imaging.noise_map.in_2d * np.invert(binned_up_mask)
+        ).all()
+
+        assert (masked_imaging_7x7.mask == binned_up_mask).all()
+
+    def test__masked_imaging__uses_signal_to_noise_limit(
+        self, imaging_7x7, mask_7x7_1_pix
+    ):
+
+        masked_imaging_7x7 = aa.MaskedImaging(
+            imaging=imaging_7x7,
+            mask=mask_7x7_1_pix,
+            settings=aa.SettingsMaskedImaging(
+                grid_class=aa.Grid, signal_to_noise_limit=1.0
+            ),
+        )
+
+        imaging_snr_limit = imaging_7x7.signal_to_noise_limited_from_signal_to_noise_limit(
+            signal_to_noise_limit=1.0
+        )
+
+        assert (
+            masked_imaging_7x7.image.in_2d
+            == imaging_snr_limit.image.in_2d * np.invert(mask_7x7_1_pix)
+        ).all()
+        assert (
+            masked_imaging_7x7.noise_map.in_2d
+            == imaging_snr_limit.noise_map.in_2d * np.invert(mask_7x7_1_pix)
+        ).all()
+
     def test__different_imaging_without_mock_objects__customize_constructor_inputs(
         self
     ):
@@ -298,7 +391,9 @@ class TestMaskedImaging:
         mask[9, 9] = False
 
         masked_imaging = aa.MaskedImaging(
-            imaging=imaging, mask=mask, psf_shape_2d=(7, 7)
+            imaging=imaging,
+            mask=mask,
+            settings=aa.SettingsMaskedImaging(psf_shape_2d=(7, 7)),
         )
 
         assert (masked_imaging.imaging.image.in_2d == np.ones((19, 19))).all()
@@ -491,3 +586,15 @@ class TestSimulatorImaging:
         assert imaging.image.in_2d == pytest.approx(
             np.array([[0.0, 1.05, 0.0], [1.3, 2.35, 1.05], [0.0, 1.05, 0.0]]), 1e-2
         )
+
+    def test__modified_noise_map(self, noise_map_7x7, imaging_7x7, mask_7x7):
+
+        masked_imaging_7x7 = aa.MaskedImaging(imaging=imaging_7x7, mask=mask_7x7)
+
+        noise_map_7x7[0] = 11.0
+
+        masked_imaging_7x7 = masked_imaging_7x7.modify_noise_map(
+            noise_map=noise_map_7x7
+        )
+
+        assert masked_imaging_7x7.noise_map[0] == 11.0
