@@ -1,3 +1,4 @@
+from autoconf import conf
 import autoarray as aa
 import autoarray.plot as aplt
 from os import path
@@ -17,7 +18,7 @@ def make_plotter_setup():
 
 @pytest.fixture(autouse=True)
 def set_config_path():
-    aa.conf.instance = aa.conf.Config(
+    conf.instance = conf.Config(
         path.join(directory, "files/plotter"), path.join(directory, "output")
     )
 
